@@ -25,11 +25,11 @@ class TestUsage(unittest.TestCase):
     def setUp(self):
         import os
         import tempfile
-        from pyramid_assetgen import AssetGenRequestMixin
-        class MyRequest(AssetGenRequestMixin, testing.DummyRequest):
-            pass
-        
-        self.config = testing.setUp(request=MyRequest())
+        #from pyramid_assetgen import AssetGenRequestMixin
+        #class MyRequest(AssetGenRequestMixin, testing.DummyRequest):
+        #    pass
+        #
+        self.config = testing.setUp(request=testing.DummyRequest, settings={}) #request=MyRequest())
         self.config.include('pyramid_assetgen')
         self.f = tempfile.NamedTemporaryFile(delete=False)
         self.f.write('{"base.js": "base-1234.js"}'.encode())
@@ -48,7 +48,7 @@ class TestUsage(unittest.TestCase):
         request = get_current_request()
         
         self.config.add_static_view('static', '/foo')
-        self.config.add_assetgen_manifest('/foo', manifest=self.f.name)
+        self.config.add_assetgen_manifest('/foo', manifest_file=self.f.name)
         
         url = request.static_url('/foo/base.js')
         self.assertTrue(url == 'http://example.com/static/base-1234.js')
@@ -60,7 +60,7 @@ class TestUsage(unittest.TestCase):
         request = get_current_request()
         
         self.config.add_static_view('static', '/foo')
-        self.config.add_assetgen_manifest('/foo', manifest=self.f.name)
+        self.config.add_assetgen_manifest('/foo', manifest_file=self.f.name)
         
         url = request.static_url('/foo/foo.js')
         self.assertTrue(url == 'http://example.com/static/foo.js')
@@ -72,7 +72,7 @@ class TestUsage(unittest.TestCase):
         request = get_current_request()
         
         self.config.add_static_view('static', '/foo')
-        self.config.add_assetgen_manifest('/foo', manifest=self.f.name)
+        self.config.add_assetgen_manifest('/foo', manifest_file=self.f.name)
         
         url = request.static_path('/foo/base.js')
         self.assertTrue(url == '/static/base-1234.js')
